@@ -1,9 +1,20 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-import sys, warnings
+import unittest
+import sys
+import warnings
 from sets import Set
-from ephem_test import *
+
+import ephem
+from ephem import (Body, Planet, Moon, Jupiter, Saturn, PlanetMoon,
+                   Date, Observer, readtle, readdb,
+                   FixedBody, EllipticalBody, HyperbolicBody,
+                   ParabolicBody, EarthSatellite,
+                   constellation)
+
+class TestError(Exception):
+    pass
 
 # The attributes which each class of object should support (these
 # lists are used by several of the functions below).
@@ -56,9 +67,9 @@ def predict_attributes(body, was_computed, was_given_observer):
 # Determine whether each kind of body supports the set of attributes
 # we believe it should.
 
-class body_suite(MyTestCase):
+class BodyTests(unittest.TestCase):
     def setUp(self):
-        self.date = date('1955/05/21')
+        self.date = Date('1955/05/21')
 
         self.obs = obs = Observer()
         obs.lat, obs.lon, obs.elev = '33:45:10', '-84:23:37', 320.0
@@ -106,7 +117,7 @@ class body_suite(MyTestCase):
                 adjective += 'centrically computed'
             else:
                 adjective = 'uncomputed'
-            raise TestError('accessing %s of %s %s '
+            raise ValueError('accessing %s of %s %s '
                             'raised %r "%s" instead of %r'
                             % (a, adjective, body,
                                t[a], t[a].args[0], p[a]))
@@ -126,13 +137,14 @@ class body_suite(MyTestCase):
         self.compare_attributes(body, True, False)
 
     def test_Named(self):
-        for named_object in (Mercury, Venus, Mars, Jupiter, Saturn,
-                             Uranus, Neptune, Pluto, Sun, Moon,
-                             Phobos, Deimos,
-                             Io, Europa, Ganymede, Callisto,
-                             Mimas, Enceladus, Tethys, Dione, Rhea,
-                             Titan, Hyperion, Iapetus, Ariel, Umbriel,
-                             Titania, Oberon, Miranda):
+        for name in ('Mercury Venus Mars Jupiter Saturn '
+                     'Uranus Neptune Pluto Sun Moon '
+                     'Phobos Deimos '
+                     'Io Europa Ganymede Callisto '
+                     'Mimas Enceladus Tethys Dione Rhea '
+                     'Titan Hyperion Iapetus Ariel Umbriel '
+                     'Titania Oberon Miranda').split():
+            named_object = getattr(ephem, name)
             self.run_body(named_object())
 
     # For each flavor of user-definable body, 
@@ -153,10 +165,10 @@ class body_suite(MyTestCase):
             try:
                 setattr(ba, attribute, value)
             except TypeError:
-                raise TestError, ('cannot modify attribute %s of %r: %s'
+                raise TestError('cannot modify attribute %s of %r: %s'
                                   % (attribute, ba, sys.exc_info()[1]))
         if not isinstance(bl, bodytype):
-            raise TestError, ('ephem database entry returned type %s'
+            raise TestError('ephem database entry returned type %s'
                               ' rather than type %s' % (type(bl), bodytype))
 
         # Now, compare the bodies to see if they are equivalent.
@@ -234,7 +246,7 @@ class body_suite(MyTestCase):
                      '2 20580  28.4694  17.3953 0004117 265.2946  '
                      '94.7172 14.99359833594524'),
             attributes={'name': 'Hubble Telescope',
-                        '_epoch': date('2004') + 296.45910607 - 1,
+                        '_epoch': Date('2004') + 296.45910607 - 1,
                         '_decay': .00000912, '_drag': .59688e-4,
                         '_inc': 28.4694, '_raan': 17.3953,
                         '_e': 4117e-7, '_ap': 265.2946, '_M': 94.7172,
@@ -254,7 +266,7 @@ class body_suite(MyTestCase):
 # indeed a major error occuring in its calculation.  This small test
 # should assure that reasonable values are returned from now on.
 
-class planet_suite(unittest.TestCase):
+class PlanetTests(unittest.TestCase):
     """See whether Jupiter Central Meridian Longitudes look good."""
     def test_jupiter(self):
         j = Jupiter('2008/10/1')
@@ -270,11 +282,8 @@ class planet_suite(unittest.TestCase):
 # Make sure the constellation function forces objects to determine
 # their position before using their right ascension and declination.
 
-class function_suite(unittest.TestCase):
+class FunctionTests(unittest.TestCase):
     def test_constellation(self):
         oneb = readdb('Orion Nebula,f,5.59,-5.45,2,2000.0,')
         oneb.compute('1999/2/28')
         self.assertEqual(constellation(oneb), ('Ori', 'Orion'))
-
-if __name__ == '__main__':
-    unittest.main()
